package com.ruoyi.dxp.mapper;

import java.util.List;
import com.ruoyi.dxp.domain.TagGroup;

/**
 * 标签分组Mapper接口
 * 
 * @author jy
 * @date 2022-11-06
 */
public interface TagGroupMapper 
{
    /**
     * 查询标签分组
     * 
     * @param id 标签分组主键
     * @return 标签分组
     */
    public TagGroup selectTagGroupById(Long id);

    /**
     * 查询标签分组列表
     * 
     * @param tagGroup 标签分组
     * @return 标签分组集合
     */
    public List<TagGroup> selectTagGroupList(TagGroup tagGroup);

    /**
     * 新增标签分组
     * 
     * @param tagGroup 标签分组
     * @return 结果
     */
    public int insertTagGroup(TagGroup tagGroup);

    /**
     * 修改标签分组
     * 
     * @param tagGroup 标签分组
     * @return 结果
     */
    public int updateTagGroup(TagGroup tagGroup);

    /**
     * 删除标签分组
     * 
     * @param id 标签分组主键
     * @return 结果
     */
    public int deleteTagGroupById(Long id);

    /**
     * 批量删除标签分组
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTagGroupByIds(Long[] ids);
}
